module FileReader
    implicit none
    
    public :: read_file
    contains
        subroutine read_file (FileName, Data)
            integer :: io
            integer :: LineLength, iostat
            integer :: TotalLength
            logical :: res
            character (len=*), intent (in) :: FileName
            character (len=*), allocatable, intent (out) :: Data
            character (len=:), allocatable :: TempData
            character (len=256) :: LineBuffer

            inquire( file=trim(FileName), exist=res )

            if (.not. res) then
                print *, "File does not exist."
                return
            end if
            
            open(newunit=io, file=trim(FileName), status="old", action="read")

            TotalLength = 0

            allocate(character(len=0) :: TempData)  ! Start with an empty string

            do
                read(io, '(A)', IOSTAT=iostat) LineBuffer
                if (iostat /= 0) exit  ! Exit loop on end-of-file or error

                ! Append the current line to TempData. CHAR(10) is a newline
                TempData = TempData // LineBuffer // CHAR(10)
            end do

            ! Allocate Data to match the length of TempData and copy it over
            allocate(character(len=len(TempData)) :: Data)
            Data = TempData

            print *, TempData

            close(io)

        end subroutine read_file
end module FileReader